==> haskell-unsafe-0.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unsafe.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unsafe
version:              0.0
visibility:           public
id:                   unsafe-0.0-BVycxWLLrcxERMQvs2Kqnx
key:                  unsafe-0.0-BVycxWLLrcxERMQvs2Kqnx
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://code.haskell.org/~thielema/unsafe/
synopsis:             Unified interface to unsafe functions
description:
    SafeHaskell introduced the notion of safe and unsafe modules.
    In order to make as many as possible modules \"safe\",
    the well-known unsafe functions were moved to distinguished modules.
    This makes it hard to write packages that work
    with both old and new versions of GHC.
    This package provides a single module @System.Unsafe@
    that exports the unsafe functions from the base package.
    It provides them in a style ready for qualification,
    that is, you should import them by

    > import qualified System.Unsafe as Unsafe

    The package also contains a script called @rename-unsafe.sh@.
    It replaces all occurrences of the original identifiers
    with the qualified identifiers from this package.
    You still have to adapt the import commands.
    It uses the @darcs-replace-rec@ script from the @darcs-scripts@ package.

category:             Control
abi:                  40b0c24163a322cb2208e8500afb700e
exposed:              True
exposed-modules:      System.Unsafe
import-dirs:          /usr/lib/ghc-9.0.1/site-local/unsafe-0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/unsafe-0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/unsafe-0.0
hs-libraries:         HSunsafe-0.0-BVycxWLLrcxERMQvs2Kqnx
depends:              base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-unsafe/html/unsafe.haddock
haddock-html:         /usr/share/doc/haskell-unsafe/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unsafe-0.0-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unsafe.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unsafe
version:              0.0
visibility:           public
id:                   unsafe-0.0-L6UZ6pDyVqJF3P5J7oCvq2
key:                  unsafe-0.0-L6UZ6pDyVqJF3P5J7oCvq2
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://code.haskell.org/~thielema/unsafe/
synopsis:             Unified interface to unsafe functions
description:
    SafeHaskell introduced the notion of safe and unsafe modules.
    In order to make as many as possible modules \"safe\",
    the well-known unsafe functions were moved to distinguished modules.
    This makes it hard to write packages that work
    with both old and new versions of GHC.
    This package provides a single module @System.Unsafe@
    that exports the unsafe functions from the base package.
    It provides them in a style ready for qualification,
    that is, you should import them by

    > import qualified System.Unsafe as Unsafe

    The package also contains a script called @rename-unsafe.sh@.
    It replaces all occurrences of the original identifiers
    with the qualified identifiers from this package.
    You still have to adapt the import commands.
    It uses the @darcs-replace-rec@ script from the @darcs-scripts@ package.

category:             Control
abi:                  33c61e64b8ea2b273f937773809b3588
exposed:              True
exposed-modules:      System.Unsafe
import-dirs:          /usr/lib/ghc-9.0.2/site-local/unsafe-0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/unsafe-0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/unsafe-0.0
hs-libraries:         HSunsafe-0.0-L6UZ6pDyVqJF3P5J7oCvq2
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-unsafe/html/unsafe.haddock
haddock-html:         /usr/share/doc/haskell-unsafe/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
